"""

ro.py > asset_type.py

This file is a conversion table for asset type IDs to asset type names.

"""

asset_types = [
    None,
    "Image",
    "TeeShirt",
    "Audio",
    "Mesh",
    "Lua",
    "Hat",
    "Place",
    "Model",
    "Shirt",
    "Pants",
    "Decal",
    "Head",
    "Face",
    "Gear",
    "Badge",
    "Animation",
    "Torso",
    "RightArm",
    "LeftArm",
    "LeftLeg",
    "RightLeg",
    "Package",
    "GamePass",
    "Plugin",
    "MeshPart",
    "HairAccessory",
    "FaceAccessory",
    "NeckAccessory",
    "ShoulderAccessory",
    "FrontAccesory",
    "BackAccessory",
    "WaistAccessory",
    "ClimbAnimation",
    "DeathAnimation",
    "FallAnimation",
    "IdleAnimation",
    "JumpAnimation",
    "RunAnimation",
    "SwimAnimation",
    "WalkAnimation",
    "PoseAnimation",
    "EarAccessory",
    "EyeAccessory",
    "EmoteAnimation",
    "Video"
]
